@@ -1,6 +1,6 @@
 """
 Contains the initialization for the autoconfiguration package. It searches for the
-config files and initializes the instance of Config.
+config files and initializes the instance of :class:`Config`.
 """
 
 import logging
@@ -9,6 +9,7 @@ from glob import glob
 from typing import List
 
 from autoconfiguration.config import Config
+from autoconfiguration.exceptions.config_class_errors import ConfigNotInitializedError
 from autoconfiguration.exceptions.config_dir_errors import ConfigDirNotFoundError
 from autoconfiguration.exceptions.config_file_errors import NoConfigFilesFoundError
 
@@ -21,7 +22,7 @@ def init(
     config_files: List[str] = None, current_env: str = None, config_dir: str = "config"
 ) -> Config:
     """
-    Initializes the Config class.
+    Initializes the :class:`Config` class.
 
     Searches for the configuration files automatically inside config_dir if no
     config_files were passed. The order of these files matters because the files can
@@ -36,7 +37,8 @@ def init(
         current_env file will always be the last file to be loaded.
     :param config_dir: Should be a path that is reachable from the directory where the
         application was executed. Default: config
-    :return: The initialized Config instance containing the values of the config files
+    :returns: The initialized :class:`Config` instance containing the values of the
+        config files
     """
     if Config._initialized:
         LOG.debug("Config was already initialized. Returning existing instance.")
@@ -54,6 +56,18 @@ def init(
     return Config(config_files[: config_files.index(current_env) + 1])
 
 
+def get():
+    """
+    Returns the initialized :class:`Config` instance.
+
+    :returns: The initialized :class:`Config` instance
+    :raise ConfigNotInitializedError: If the :class:`Config` was not initialized
+    """
+    if not Config._initialized:
+        raise ConfigNotInitializedError()
+    return Config()
+
+
 def _validate_config_files(config_files: List[str], config_dir: str) -> List[str]:
     if config_files is None:
         config_files = glob(os.path.join(config_dir, f"*{CONFIG_EXTENSION}"))
