@@ -1,9 +1,9 @@
-"""Contains the Config class that loads the configuration files."""
+"""Contains the :class:`Config` class that loads the configuration files."""
 
 import logging
 from collections import namedtuple
 from configparser import ConfigParser
-from typing import List
+from typing import List, Union
 
 from autoconfiguration.infrastructure.singleton import Singleton
 
@@ -11,6 +11,10 @@ from autoconfiguration.infrastructure.singleton import Singleton
 LOG = logging.getLogger(__name__)
 
 
+def _valid_name(name: str) -> str:
+    return name.replace("-", "_")
+
+
 class Config(metaclass=Singleton):
     """
     Loads the configuration files and will contain all values of these files.
@@ -21,12 +25,15 @@ class Config(metaclass=Singleton):
         self._config.read(config_files)
 
         self._sections = {
-            section: namedtuple(section.title(), self._config[section].keys())(
-                *self._config[section].values()
-            )
+            _valid_name(section): self._create_namedtuple(section)
             for section in self._config.sections()
         }
         LOG.debug("Generated config: %s", self._sections)
 
+    def _create_namedtuple(self, section: str):
+        keys = (_valid_name(key) for key in self._config[section].keys())
+        values = self._config[section].values()
+        return namedtuple(_valid_name(section.title()), keys)(*values)
+
     def __getattr__(self, name):
         return self._sections[name]
